// C Source File
// Created 7/31/01; 6:22:54 PM
/*
	Error Simulator 2001 by Greg Dietsche
		Simulates various error conditions that may be encountered on
		the TI-89 and TI-92+ Graphing Calculators
*/

#define OPTIMIZE_ROM_CALLS    // Use ROM Call Optimization
#define NO_EXIT_SUPPORT
#include <tigcclib.h>         // Include All Header Files

short _ti89;                  // Produce .89Z File
short _ti92plus;              // Produce .9XZ File

void BuildEditorMenu(volatile HANDLE hMenuStruct);

volatile HANDLE hMenuStruct;
volatile HANDLE hMenu;
short mnuResult;
	
// Main Function
void _main(void)
{
	LCD_BUFFER b;
	LCD_save(b);
	
	ClrScr();
	FontSetSys(F_6x8);
	DrawStrXY(6*2,20,"*Error Simulator 2001*",A_NORMAL);
	DrawStrXY(6*5,30,"By: Greg Dietsche",A_NORMAL);
	DrawStrXY(0,50,"KERNEL:",A_NORMAL);
	
	if(*(short*)0x30)
	{
		if(*(unsigned short*)0x32 == 0x4B4E)//0x4B4E==KN
			DrawStrXY(42,50,"KerNO",A_NORMAL);
		else
			DrawStrXY(42,50,"DoorsOS Compatible",A_NORMAL);
	}
	else
	{
		DrawStrXY(42,50,"NONE",A_NORMAL);
	}
	
	hMenuStruct=MenuNew (2, 0, 0);
	BuildEditorMenu(hMenuStruct);
	hMenu = MenuBegin(HLock (hMenuStruct), 0, 0, 0);
	
	if((mnuResult=MenuKey(hMenu,ngetchx())))
	{
		LCD_restore(b);
		switch (mnuResult)
		{
			case 2:
				asm(".word 0xF800 + 0x19E");
				DrawStrXY(0,20,"Rom Call 0x19E Executed",A_NORMAL);
				ngetchx();
				break;
			case 3:
				asm(".word 0xF000");
				break;
			case 4://trace
				asm("trap #0xC;move #0x8000,%sr");
				break;
			case 5:
				asm("Infinity: jmp Infinity");
				break;
			case 6:
				asm("move.l #3,%a0; move.l #3,(%a0)");
				break;
			case 7:
			 asm("ILLEGAL");
			 break;
			case 8:
				asm("DIVU #0,%d0");
				break;
			case 9:
				asm("move.l #4,%d0;chk #2,%d0");
				break;
			case 10:
				asm("move #0x2,%CCR;TRAPV");
				break;
			case 11:
				asm("rte");
				break;
			case 12:
				asm("move 2,4");
				break;
			case 13:
			 asm("trap #5");
			 break;
			case 14:
			 asm("trap #6");
			 break;
			case 15:
			 asm("trap #7");
			 break;
			case 16:
			 asm("trap #8");
			 break;
			case 17:
			 asm("trap #13");
			 break;
			case 18:
			 asm("trap #14");
			 break;
			case 19:
			 asm("trap #15");
			 break;
			default:
			break;
		}
	}
	
	MenuEnd(hMenu);
	HeapFree(hMenuStruct);
	LCD_restore(b);
}

void BuildEditorMenu(volatile HANDLE hMenuStruct)
{
MenuAddText(hMenuStruct, 0, "Error",						 				1, 0);
MenuAddText(hMenuStruct, 0, "Line 1111",								50, 0);
MenuAddText(hMenuStruct, 50, "$F99E (Good)",						2, 0);
MenuAddText(hMenuStruct, 50, "$F000 (Bad)",							3, 0);
MenuAddText(hMenuStruct, 1, "Infinite Loop",						5, 0);
MenuAddText(hMenuStruct, 1, "Address Error",						6, 0);
MenuAddText(hMenuStruct, 1, "Illegal Instruction",			7, 0);
MenuAddText(hMenuStruct, 1, "Divide By Zero",						8, 0);
MenuAddText(hMenuStruct, 1, "CHK",											9, 0);
MenuAddText(hMenuStruct, 1, "TRAPV",										10, 0);
MenuAddText(hMenuStruct, 1, "Privilege Violation",			11, 0);
MenuAddText(hMenuStruct, 1, "Protected Memory",					12, 0);
MenuAddText(hMenuStruct, 0, "Trap",											51, 0);
MenuAddText(hMenuStruct, 51, "5",												13, 0);
MenuAddText(hMenuStruct, 51, "6",												14, 0);
MenuAddText(hMenuStruct, 51, "7",												15, 0);
MenuAddText(hMenuStruct, 51, "8",												16, 0);
MenuAddText(hMenuStruct, 51, "13",											17, 0);
MenuAddText(hMenuStruct, 51, "14",											18, 0);
MenuAddText(hMenuStruct, 51, "15",											19, 0);
MenuAddText(hMenuStruct, 0, "Exit",							 				53, 0);
}



